[libgit2-glib] Rename rename reflog api to log



commit b08c4ae4b2e9be5fe0c23773357239989decdc16
Author: Ignacio Casal Quinteiro <icq gnome org>
Date:   Mon Jun 23 16:26:31 2014 +0200

    Rename rename reflog api to log

 libgit2-glib/ggit-ref.c |   14 +++++++-------
 libgit2-glib/ggit-ref.h |    4 ++--
 2 files changed, 9 insertions(+), 9 deletions(-)
---
diff --git a/libgit2-glib/ggit-ref.h b/libgit2-glib/ggit-ref.h
index 8a4b840..e87ff21 100644
--- a/libgit2-glib/ggit-ref.h
+++ b/libgit2-glib/ggit-ref.h
@@ -104,10 +104,10 @@ void            ggit_ref_delete             (GgitRef        *ref,
 GgitObject     *ggit_ref_lookup             (GgitRef        *ref,
                                              GError        **error);
 
-GgitReflog     *ggit_ref_get_reflog         (GgitRef        *ref,
+GgitReflog     *ggit_ref_get_log            (GgitRef        *ref,
                                              GError        **error);
 
-void            ggit_ref_delete_reflog      (GgitRef        *ref,
+void            ggit_ref_delete_log         (GgitRef        *ref,
                                              GError        **error);
 
 gboolean        ggit_ref_is_tag             (GgitRef        *ref);


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/libgit2-glib/ggit-ref.c b/libgit2-glib/ggit-ref.c
index 3ff3636..d2ad648 100644
--- a/libgit2-glib/ggit-ref.c
+++ b/libgit2-glib/ggit-ref.c
@@ -464,7 +464,7 @@ ggit_ref_lookup (GgitRef  *ref,
 }
 
 /**
- * ggit_ref_get_reflog:
+ * ggit_ref_get_log:
  * @ref: a #GgitRef.
  * @error: a #GError for error reporting, or %NULL.
  *
@@ -474,8 +474,8 @@ ggit_ref_lookup (GgitRef  *ref,
  * Returns: (transfer full): the reflog.
  */
 GgitReflog *
-ggit_ref_get_reflog (GgitRef  *ref,
-                     GError  **error)
+ggit_ref_get_log (GgitRef  *ref,
+                  GError  **error)
 {
        git_reflog *reflog;
        git_reference *nref;
@@ -500,15 +500,15 @@ ggit_ref_get_reflog (GgitRef  *ref,
 }
 
 /**
- * ggit_ref_delete_reflog:
+ * ggit_ref_delete_log:
  * @ref: a #GgitRef.
  * @error: a #GError for error reporting, or %NULL.
  *
  * Deletes the reflog for @ref, on error @error is set.
  */
 void
-ggit_ref_delete_reflog (GgitRef  *ref,
-                        GError  **error)
+ggit_ref_delete_log (GgitRef  *ref,
+                     GError  **error)
 {
        git_reference *nref;
        gint ret;
@@ -500,15 +500,15 @@ ggit_ref_get_reflog (GgitRef  *ref,
  * @error: a #GError for error reporting, or %NULL.
  *
- * Deletes the reflog for @ref, on error @error is set.
+ * Deletes the log for @ref, on error @error is set.
  */
 void